FullPageView class

Inheritance

Constructors

FullPageView({Key? key, required List<StoryItem>? storiesMapList, required int? storyNumber, TextStyle? fullPagetitleStyle, bool? displayProgress, Color? fullpageVisitedColor, Color? fullpageUnvisitedColor, bool? showThumbnailOnFullPage, double? fullpageThumbnailSize, bool? showStoryNameOnFullPage, Color? storyStatusBarColor, Function? onPageChanged, Duration? autoPlayDuration})
const

Properties

autoPlayDuration → Duration?
Duration after which next story is displayed Default value is infinite.
final
displayProgress → bool?
Choose whether progress has to be shown
final
fullpageThumbnailSize → double?
Size of the top left image
final
fullPagetitleStyle → TextStyle?
final
fullpageUnvisitedColor → Color?
Color for non visited region in progress indicator
final
fullpageVisitedColor → Color?
Color for visited region in progress indicator
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPageChanged → Function?
Function to run when page changes
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showStoryNameOnFullPage → bool?
Whether image has to be show on top left of the page
final
showThumbnailOnFullPage → bool?
Whether image has to be show on top left of the page
final
storiesMapList → List<StoryItem>?
final
storyNumber → int?
final
storyStatusBarColor → Color?
Status bar color in full view of story
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FullPageViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited